@@ -1,7 +1,7 @@
 #include <cpp11.hpp>
 #include <mysql.h>
 
-#include <plogr.h>
+#include <vector>
 
 #if MYSQL_VERSION_ID >= 80000 && MYSQL_VERSION_ID < 100000
 #define my_bool bool
